@@ -1,11 +1,12 @@
 import argparse
-import colorama
 import json
 import os
 import random
 import subprocess
 import sys
 
+import colorama
+
 # pytest is a required module
 try:
     exec("import pytest")
@@ -100,7 +101,10 @@ with open("test_values.txt", "r", encoding="utf-8") as file:
                     for j in range(1, len(args[0])):
                         string += " " + str(args[0][j])
                 partial_output = ""
-                output.append(string)
+                if string[-2:] == ": " or string[-2:] == "? " or string[-2:] == "= ":
+                    output.append(string)
+                else:
+                    output.append(string.rstrip())
 
         program.input = mock_input
 
@@ -139,7 +143,7 @@ with open("test_values.txt", "r", encoding="utf-8") as file:
         program.main()
 
         if partial_output != "":
-            output.append(partial_output)
+            output.append(partial_output.rstrip())
 
         with open("obtained_result.txt", "w", encoding="utf-8") as file:
             # saved as json because it is a list
@@ -150,7 +154,33 @@ with open("test_values.txt", "r", encoding="utf-8") as file:
         )
 
 
+def check_latest_version():
+    response = requests.get("https://pypi.org/pypi/mclibre-python-testing-client/json")
+    latest_version = response.json()["info"]["version"]
+    if sys.version_info >= (3, 8):
+        from importlib import metadata
+    else:
+        import importlib_metadata as metadata
+    actual_version = metadata.version("mclibre_python_testing_client")
+    if latest_version != actual_version:
+        print(
+            f"{colorama.Fore.YELLOW}[AVISO] Está utilizando la versión {actual_version} de MPTC.{colorama.Style.RESET_ALL}"
+        )
+        print(
+            f"{colorama.Fore.YELLOW}        Actualice a la versión {latest_version} con el comando:{colorama.Style.RESET_ALL}"
+        )
+        print(
+            f"{colorama.Fore.WHITE}        pip install --upgrade mclibre-python-testing-client{colorama.Style.RESET_ALL}"
+        )
+        print(
+            f"{colorama.Fore.YELLOW}        Pulse la tecla [Intro] o [Return] para continuar.{colorama.Style.RESET_ALL}"
+        )
+        input()
+
+
 def main():
+    check_latest_version()
+
     EXECUTION_ERROR = "Execution error"
     SYNTAX_ERROR = "Syntax error"
 
@@ -172,7 +202,10 @@ def main():
     )
 
     parser.add_argument(
-        "-w", "--write", action="store", help="descarga y guarda los valores de test en un archivo"
+        "-w",
+        "--write",
+        action="store",
+        help="descarga y guarda los valores de test en un archivo",
     )
 
     parser.add_argument(
@@ -185,7 +218,9 @@ def main():
         testable = testable[2:]
     if testable.find("\\") != -1 or testable.find("/") != -1:
         print(f"Error: No se permiten caminos absolutos o relativos [{testable}].")
-        print("Por favor, ejecute MPTC en el directorio en el que se encuentra su programa.")
+        print(
+            "Por favor, ejecute MPTC en el directorio en el que se encuentra su programa."
+        )
         exit()
     elif not (os.path.isfile(testable)):
         print(
@@ -202,8 +237,7 @@ def main():
             print(f"Error: No se encuentra el fichero {args.read}.")
             exit()
     else:
-        server_url = "https://smagris3.uv.es/mclibre/mclibre-python-testing/mclibre_python_testing_server.py"
-        #server_url = "http://localhost/mclibre/consultar/python-testing/server/mclibre_python_testing_server.py"
+        server_url = "https://www.mclibre.org/mclibre-python-testing/mclibre_python_testing_server.py"
 
         random_id = random.randint(0, 100_000)
         json_request = {
@@ -212,22 +246,16 @@ def main():
             "params": {"version": "0.1", "exercise-id": args.exercise_id},
             "id": random_id,
         }
-        #print (json.dumps(json_request))
         r = requests.post(server_url, data=json.dumps(json_request))
-        # print(r.text)
         values = r.json()
-        # print(values)
-        # for i in values["result"]:
-           # print(i["input"])
-           # print(i["random"])
-           # print(i["output"])
-           # print()
 
     if args.write is not None:
         try:
             with open(args.write, "w", encoding="utf-8") as file:
                 file.write(json.dumps(values, ensure_ascii=False))
-                print(f"Los valores de prueba se han guardado en el fichero {file.name}")
+                print(
+                    f"Los valores de prueba se han guardado en el fichero {file.name}"
+                )
         except:
             print(f"Error: No se ha podido crear el fichero {args.write}.")
             exit()
@@ -279,13 +307,29 @@ def main():
                     )
                     p.wait()
                 failed_message = False
+                too_many_inputs = False
+                too_many_randoms = False
 
                 with open("stdout.txt", "r") as file:
                     line = file.readline()
                     while line:
-                        if line.rstrip().find("AssertionError") != -1:
+                        if line.rstrip().find("1 failed") != -1:
                             failed_message = True
+                        if (
+                            line.rstrip().find(">       return input_values.pop(0)")
+                            != -1
+                        ):
+                            too_many_inputs = True
+                        if line.rstrip().find(">   program.random.randrange") != -1:
+                            too_many_randoms = True
+                        if line.rstrip().find(">   program.randrange") != -1:
+                            too_many_randoms = True
+                        if line.rstrip().find(">   program.random.choice") != -1:
+                            too_many_randoms = True
+                        if line.rstrip().find(">   program.choice") != -1:
+                            too_many_randoms = True
                         line = file.readline()
+
                 if failed_message:
                     print(f"Test {test_counter} fallado. ")
                 else:
@@ -372,15 +416,26 @@ def main():
                                 print(f"{j} ", end="")
                             print()
                             print()
-
-                    if i[2] == SYNTAX_ERROR:
+                    if too_many_inputs:
+                        print(
+                            "  El programa pide al usuario más datos de los esperados."
+                        )
+                        print()
+                    elif too_many_randoms:
+                        print(
+                            "  El programa parece generar más números aleatorios de los esperados."
+                        )
+                        print()
+                    elif i[2] == SYNTAX_ERROR:
                         print(
                             "  El programa parece tener un error de sintaxis. Por favor, compruebe que puede ejecutarlo manualmente."
                         )
+                        print()
                     elif i[2] == EXECUTION_ERROR:
                         print(
-                            "  El programa no puede jecutarse. Por favor, compruebe que contiene la función main()."
+                            "  El programa no puede ejecutarse. Por favor, compruebe que contiene la función main()."
                         )
+                        print()
                     else:
                         if len(i[0]["output"]) != len(i[1]):
                             print(
@@ -399,11 +454,11 @@ def main():
                             if 0 <= j < len(i[0]["output"]):
                                 print(f'  Resultado esperado: "{i[0]["output"][j]}"')
                             else:
-                                print(f"  No se esperaba ningún resultado.")
+                                print("  No se esperaba ningún resultado.")
                             if 0 <= j < len(i[1]):
                                 print(f'  Resultado obtenido: "{i[1][j]}"')
                             else:
-                                print(f"  No se obtuvo ningún resultado.")
+                                print("  No se obtuvo ningún resultado.")
                             print()
                 if len(errorReport) > 1:
                     print(
